/*

    This program is used to create the Quick-Reference Guide included with
    the Klipper Library Distribution zip file.

    When run in the directory that contains all your .HDR files, this program
    will create a quick-reference entry for each source file it finds.

    The resulting text file is called QUICKREF.TXT.

    COPY MAKEQREF.EXE to the dir that contains all the Klipper Lib .HDR files
    and run it there.

    For those who purchased a source code liscence, COPY all your .PRG files
    to .HDR files (in another dir) and run the program there.

    Note that the structure of the source code header files MUST be:

            FUNCTION:

            PARAMETERS:

            SHORT:

            DESCRIPTION:

            NOTE:

            EXAMPLE:


    Each of the above tokens must be on a line by itself.  That is, for
    instance, the function token cannot be "FUNCTION: _FuncName()".

*/

#include "fileio.ch"
#include "klipper.ch"

FUNCTION main()

LOCAL    acHdrFiles := directory("*.HDR")
LOCAL    nHandle := 0
LOCAL    oHandle := fcreate("QUICKREF.TXT")
LOCAL    i := 0
LOCAL    cLine := ""

asort(acHdrFiles,,, {|x,y| x[1] < y[1]})

if oHandle > 0

    for i = 1 to len(acHdrFiles)

        nHandle = fopen(acHdrFiles[i,1])

        if nHandle > 0

            ? "Extracting Q-Reference text: ", acHdrFiles[i,1]

            // skip to the function declaration
            while substr(ltrim(_Readline(nHandle)),1,9) != "FUNCTION:" .and. !_FEOF(nHandle) ; end

            while !_FEOF(nHandle)

                cLine = _Readline(nHandle)

                if substr(ltrim(cLine),1,11) == "PARAMETERS:" .or. _FEOF(nHandle)
                    EXIT
                endif

                if empty(cLine)
                    loop
                endif

                _FWriteLine(oHandle,CRLF+cLine)

            end

            // skip to the short description
            while substr(ltrim(_Readline(nHandle)),1,6) != "SHORT:" .and. !_FEOF(nHandle) ; end

            while !_FEOF(nHandle)

                cLine = _Readline(nHandle)

                if substr(ltrim(cLine),1,12) == "DESCRIPTION:" .or. _FEOF(nHandle)
                    EXIT
                endif

                if empty(cLine)
                    loop
                endif

                _FWriteLine(oHandle,CRLF+cLine)

            end

        else
            _Terminate("Aaaaaaaaaaaghhhhhhhhh!  Something went horribly wrong opening: "+acHdrFiles[i,1])
        endif

        _FWriteLine(oHandle,CRLF+repl("-",80))
        fclose(nHandle)

    next

    fclose(oHandle)

else

    _Terminate("Aaaaaaaaghhhhhh!  Something went horribly wrong with the QUICKREF.TXT file!!!")

endif

RETURN(NIL)

